@@ -26,6 +26,10 @@ import time
 
 
 class EventStreamBase(object):
+    """
+    a base class for connecting to kafka
+    """
+
     id = time.time()
     event_string = "events"
     state_separator = "_"
@@ -58,11 +62,14 @@ class EventStreamBase(object):
 
     log = "EventStreamBase " + str(id) + " "
 
-    def __init__(self, id_in):
+    def __init__(self, id_in, counter_in=None):
         self.id = id_in
+        self.counter = counter_in
         self.log = self.log + str(self.id) + ": "
 
     def build_topic_list(self):
+        """build a list of topics from the configs
+        """
         result = []
 
         for c_state in self.config_states:
@@ -78,6 +85,12 @@ class EventStreamBase(object):
         return result
 
     def build_topic_name(self, state, relation_type=''):
+        """build the name of the topic for a given state
+
+        Arguments:
+            state: the state to get the topic for
+            relation_type: optional, in case it has it's own topic
+        """
         result = self.event_string + self.state_separator + state
 
         if relation_type != '':
@@ -85,11 +98,22 @@ class EventStreamBase(object):
         return result
 
     def get_topic_name_event(self, event):
+        """this will resolve an event to it's respected kafka topic
+
+        Arguments:
+            key: the event to be resolved
+        """
         state = event.get('state')
         relation_type = event.get('relation_type')
         return self.get_topic_name(state, relation_type)
 
     def get_topic_name(self, state, relation_type=''):
+        """get the name of the topic for a given state
+
+        Arguments:
+            state: the state to get the topic for
+            relation_type: optional, in case it has it's own topic
+        """
         result = self.event_string + self.state_separator + state
 
         # if a relation type is set and has is own topic
@@ -104,6 +128,11 @@ class EventStreamBase(object):
     #     #data['url']
 
     def resolve_event(self, event):
+        """this will resolve an event to it's respected kafka topic
+
+        Arguments:
+            key: the event to be resolved
+        """
         topic_name = self.build_topic_name(event['state'], event['relation_type'])
         if topic_name in self.topics:
             return topic_name
